@@ -45,6 +45,9 @@
 #endif
 
 #if defined(__WIN32__)
+#include <w32api.h>
+#define _WIN32_WINNT Windows2000
+#define WINVER Windows2000
 #include <windows.h>
 #define GNUSTEP_BASE_SOCKET_MESSAGE (WM_USER + 1)
 #endif
@@ -92,10 +95,10 @@
 #endif
 
 /* The following group of lines maintained by the gstep-base configure */
-#define GNUSTEP_BASE_VERSION            2.0.1
+#define GNUSTEP_BASE_VERSION            2.1.0
 #define GNUSTEP_BASE_MAJOR_VERSION      2
-#define GNUSTEP_BASE_MINOR_VERSION      0
-#define GNUSTEP_BASE_SUBMINOR_VERSION   1
+#define GNUSTEP_BASE_MINOR_VERSION      1
+#define GNUSTEP_BASE_SUBMINOR_VERSION   0
 #define GNUSTEP_BASE_GCC_VERSION        2.9.5
 
 #define OBJC_MALLOC(VAR, TYPE, NUM) \
